VEqual

Struct VEqual 

pub struct VEqual { /* private fields */ }
Arranges children from top to bottom, similar to VStack, but gives every child equal space and does not suffer from the Full alignment caveat.

Implementations

Source

impl VEqual

pub fn new() -> Self

Creates a new VEqual with no children, 0 spacing, and (Begin, Begin) alignment.

pub fn with_child(self, index: NodeIndex) -> Self

Add a new child to the list.

pub fn with_align(self, align: (Alignment, Alignment)) -> Self

Set the horizontal and vertical alignment.

pub fn add_child(&mut self, index: NodeIndex)

Add a child to the list. The child will appear at the end.

pub fn len(&self) -> usize

Returns the number of children in the list.

pub fn is_empty(&self) -> bool

Returns true if the list is empty.

Equivalent to len() == 0.

pub fn remove_child(&mut self, index: usize, tree: &mut UiTree) -> bool

Remove a child from the list.

Returns true if the child was removed.

pub fn set_child_position(&mut self, index: usize, position: usize) -> bool

Move a child to a new index.

Returns true if the child was moved.

pub fn get_child_index(&self, index: usize) -> Option<NodeIndex>

Returns the tree index associated with a child at a given list index.