Clamp

Struct Clamp 

pub struct Clamp {
    pub max_override: (f32, f32),
    pub anchor: (Anchor, Anchor),
    /* private fields */
}
Limits a node’s maximum size.

If the node’s minimum size exceeds the maximum, the minimum takes precedence.

Fields

max_override: (f32, f32)

The maximum size to maintain.

anchor: (Anchor, Anchor)

The position to place the shrunken space. The child is then aligned within the new space.

Implementations

Source

impl Clamp

pub fn new() -> Self

Creates a new Clamp with no child, a size limit of 0, default anchoring, and (Begin, Begin) alignment.

The default maximum has no effect, as the maximum is immediately overridden by the child’s min size.

pub fn with_child(self, index: NodeIndex) -> Self

bind a child node.

Panics

If there is already a child node.

pub fn with_align(self, align: (Alignment, Alignment)) -> Self

Set the horizontal and vertical alignment.

pub fn with_anchor(self, anchor: (Anchor, Anchor)) -> Self

Set the horizontal and vertical anchor mode for the shrunken space.

pub fn with_max(self, max: (f32, f32)) -> Self

Set the maximum size.

If the maximum size is smaller than the minimum size, the minimum takes precedence.

pub fn add_child(&mut self, index: NodeIndex)

Bind a child node to the node.

Panics

If there is already a child node.

pub fn get_child(&self) -> Option<NodeIndex>

Get the tree index of the child.