Margin

Struct Margin 

pub struct Margin {
    pub left: f32,
    pub right: f32,
    pub top: f32,
    pub bottom: f32,
    /* private fields */
}
Maintains a margin around a singular child.

Using a negative margin will expand the minimum size but not restrict the space of the child. This can be used to make the child occupy more space than it would otherwise.

The space is restricted by the margin before alignment is applied, so if the child’s alignment is Center the child will be centered based on the restricted space, resulting in an unexpected shift if top != bottom or left != right. All other alignments are unaffected.

Maintains the margin as a minimum size even if child is None, however, once a child is assigned, it cannot be removed. If you intend to use the margin as a minimum size, you should use Minimum with no child instead.

Fields

left: f32

The left margin amount.

right: f32

The right margin amount.

top: f32

The top margin amount.

bottom: f32

The bottom margin amount.

Implementations

Source

impl Margin

pub fn new() -> Self

Creates a new Margin with no child, no margin, and (Begin, Begin) alignment.

pub fn with_child(self, index: NodeIndex) -> Self

Bind a child node.

Panics

If there is already a child node.

pub fn with_align(self, align: (Alignment, Alignment)) -> Self

Set the horizontal and vertical alignment.

pub fn with_margins(self, left: f32, right: f32, top: f32, bottom: f32) -> Self

Set the left, right, top, and bottom margins.

pub fn with_equal_x(self, lr: f32) -> Self

Set the left and right margins to the same value.

pub fn with_equal_y(self, tb: f32) -> Self

Set the top and bottom margins to the same value.

pub fn with_equal_xy(self, lr: f32, tb: f32) -> Self

Set both the left and right margins, and both the top and bottom margins.

pub fn with_equal(self, margin: f32) -> Self

Set the left, right, top, and bottom margins to the same value.

pub fn with_left(self, left: f32) -> Self

Set the left margin.

pub fn with_right(self, right: f32) -> Self

Set the right margin.

pub fn with_top(self, top: f32) -> Self

Set the top margin.

pub fn with_bottom(self, bottom: f32) -> Self

Set the bottom margin.

pub fn get_child(&self) -> Option<NodeIndex>

Get the tree index of the child.