Spacer

Struct Spacer 

pub struct Spacer { /* private fields */ }
Behaves identically to a childless Minimum. It has a fixed size.

Implementations

Source

impl Spacer

pub fn new() -> Self

Creates a new Spacer with no size and (Begin, Begin) alignment.

pub fn sized(size: (f32, f32)) -> Self

Creates a new Spacer with the given size and (Begin, Begin) alignment.

Equivalent to Spacer::new().with_size(size).

pub fn with_align(self, align: (Alignment, Alignment)) -> Self

Set the horizontal and vertical alignment.

pub fn with_size(self, size: (f32, f32)) -> Self

Set the size.

Panics

If size is negative

pub fn set_size(&mut self, size: (f32, f32))

Set the size.

Panics

If size is negative

pub fn get_size(&self) -> (f32, f32)

Get the size.