AspectRatio

Struct AspectRatio 

pub struct AspectRatio {
    pub anchor: (Anchor, Anchor),
    /* private fields */
}
Expands the horizontal or vertical dimensions of a child to maintain an aspect ratio.

An anchor must be specified to determine where the child should be placed after the aspect ratio is applied.

Once the child is added, it cannot be removed.

Fields

anchor: (Anchor, Anchor)

The position to place the shrunken space. The child is then aligned within the new space.

Implementations

Source

impl AspectRatio

pub fn new() -> Self

Creates a new AspectRatio with no child, default anchoring, a 1:1 ratio, and (Begin, Begin) alignment.

pub fn with_child(self, index: NodeIndex) -> Self

Create a child node and bind it to the node.

Panics

If there is already a child node.

pub fn with_align(self, align: (Alignment, Alignment)) -> Self

Set the horizontal and vertical alignment.

pub fn with_anchor(self, anchor: (Anchor, Anchor)) -> Self

Set the horizontal and vertical anchor.

pub fn with_ratio(self, ratio: f32) -> Self

Set the horizontal:vertical ratio to be maintained.

Panics

If ratio <= 0.0.

pub fn get_ratio(&self) -> f32

Returns the current ratio.

pub fn set_ratio(&mut self, ratio: f32)

Set the horizontal:vertical ratio to be maintained.

Panics

If ratio <= 0.0.

pub fn add_child(&mut self, index: NodeIndex)

Bind a child node.

Panics

If there is already a child node.

pub fn get_child(&self) -> Option<NodeIndex>

Get the tree index of the child.