VStack

Struct VStack 

pub struct VStack { /* private fields */ }
A vertical arrangement of UI nodes with configurable spacing.

Nodes can be reordered and added/removed at any time.

Nodes always appear at their minimum size vertically, regardless of alignment. Horizontal alignment still applies.

Implementations

Source

impl VStack

pub fn new() -> Self

pub fn with_child(self, index: NodeIndex) -> Self

Add a new child to the stack.

pub fn with_align(self, align: (Alignment, Alignment)) -> Self

Set the horizontal and vertical alignment.

A vertical alignment of Full will not function as expected, and will have the same appearance as Begin.

pub fn with_spacing(self, spacing: f32) -> Self

Set the spacing between children. Defaults to 0.

No spacing appears before the first child or after the last child.

pub fn set_spacing(&mut self, spacing: f32)

Set the spacing between children.

See with_spacing for details.

pub fn add_child(&mut self, index: NodeIndex)

Add a child to the stack. The child will appear at the end.

pub fn len(&self) -> usize

Returns the number of children in the stack.

pub fn is_empty(&self) -> bool

Returns true if the stack is empty.

Equivalent to len() == 0.

pub fn remove_child(&mut self, index: usize, tree: &mut UiTree) -> bool

Remove a child from the stack.

Returns true if the child was removed.

pub fn set_child_position(&mut self, index: usize, position: usize) -> bool

Move a child to a new index.

Returns true if the child was moved.

pub fn get_child_index(&self, index: usize) -> Option<NodeIndex>

Returns the tree index associated with a child at a given stack index.