PartialTree

Struct PartialTree 

pub struct PartialTree { /* private fields */ }
A UiTree that does not have a full tree structure assigned.

The API for this struct only contains a method to add a node to the tree and a method to complete the tree. This comes at the benefit of not requiring a root node at construction.

It is used internally by the ui! macro, but can also be used manually.

Implementations

Source

impl PartialTree

pub fn new() -> Self

Constructs a new empty tree.

pub fn add_node(&mut self, node: impl UiNode) -> TdIndex

Adds a node to the tree and returns its index.

pub fn complete(self, root: TdIndex) -> UiTree

Completes a partial tree into a full UI tree.

Returns a new UI tree with the given root node and the arena and cache from self.

Indices are preserved.

Panics

If the tree is malformed, or if the root node is not present in the arena.