pub struct Clamp {
pub max_override: (f32, f32),
pub anchor: (Anchor, Anchor),
/* private fields */
}Expand description
Limits a node’s maximum size.
If the node’s minimum size exceeds the maximum, the minimum takes precedence.
Fields
max_override: (f32, f32)The maximum size to maintain.
anchor: (Anchor, Anchor)The position to place the shrunken space. The child is then aligned within the new space.
Implementations
Sourceimpl Clamp
impl Clamp
Sourcepub fn with_child(self, index: NodeIndex) -> Self
pub fn with_child(self, index: NodeIndex) -> Self
Sourcepub fn with_align(self, align: (Alignment, Alignment)) -> Self
pub fn with_align(self, align: (Alignment, Alignment)) -> Self
Set the horizontal and vertical alignment.
Sourcepub fn with_anchor(self, anchor: (Anchor, Anchor)) -> Self
pub fn with_anchor(self, anchor: (Anchor, Anchor)) -> Self
Set the horizontal and vertical anchor mode for the shrunken space.
Sourcepub fn with_max(self, max: (f32, f32)) -> Self
pub fn with_max(self, max: (f32, f32)) -> Self
Set the maximum size.
If the maximum size is smaller than the minimum size, the minimum takes precedence.