pub struct Overlap { /* private fields */ }Expand description
A node that contains many children which are stacked on top of each other and do not interact.
Implementations
Sourceimpl Overlap
impl Overlap
Sourcepub fn with_child(self, index: NodeIndex) -> Self
pub fn with_child(self, index: NodeIndex) -> Self
Add a new child to the list.
Sourcepub fn with_align(self, align: (Alignment, Alignment)) -> Self
pub fn with_align(self, align: (Alignment, Alignment)) -> Self
Set the horizontal and vertical alignment of the container, not the children.
Sourcepub fn add_child(&mut self, index: NodeIndex)
pub fn add_child(&mut self, index: NodeIndex)
Add a child to the list. The child will appear on top (last-visited).
Sourcepub fn remove_child(&mut self, index: usize, tree: &mut UiTree) -> bool
pub fn remove_child(&mut self, index: usize, tree: &mut UiTree) -> bool
Remove a child from the list.
Returns true if the child was removed.
Sourcepub fn set_child_position(&mut self, index: usize, position: usize) -> bool
pub fn set_child_position(&mut self, index: usize, position: usize) -> bool
Move a child to a new index. Lower indices are visited first.
Returns true if the child was moved.
Sourcepub fn get_child_index(&self, index: usize) -> Option<NodeIndex>
pub fn get_child_index(&self, index: usize) -> Option<NodeIndex>
Returns the tree index associated with a child at a given list index.