Size constraint nodes.
Margin wraps a single child in a runtime-configurable margin.
Minimum wraps a single child with a configurable minimum size, allowing for the child to be
precisely aligned or given a fixed size. It can also be used without a child to create an empty,
fixed-size space.
Alignment caveats with Margin
When using Center on the child, the child will be aligned to the center of the space after
the restriction from the margin is applied. All other alignments hug the edges, giving the
correct appearances.
To avoid the alignment shift while keeping centering, have symmetrical margins or use
Minimum with the intended area.