pub struct AspectRatio {
pub anchor: (Anchor, Anchor),
/* private fields */
}Expand description
Expands the horizontal or vertical dimensions of a child to maintain an aspect ratio.
An anchor must be specified to determine where the child should be placed after the aspect ratio is applied.
Once the child is added, it cannot be removed.
Fields
anchor: (Anchor, Anchor)The position to place the shrunken space. The child is then aligned within the new space.
Implementations
Sourceimpl AspectRatio
impl AspectRatio
Sourcepub fn with_child(self, index: NodeIndex) -> Self
pub fn with_child(self, index: NodeIndex) -> Self
Sourcepub fn with_align(self, align: (Alignment, Alignment)) -> Self
pub fn with_align(self, align: (Alignment, Alignment)) -> Self
Set the horizontal and vertical alignment.
Sourcepub fn with_anchor(self, anchor: (Anchor, Anchor)) -> Self
pub fn with_anchor(self, anchor: (Anchor, Anchor)) -> Self
Set the horizontal and vertical anchor.
Sourcepub fn with_ratio(self, ratio: f32) -> Self
pub fn with_ratio(self, ratio: f32) -> Self