pub struct VStack { /* private fields */ }Expand description
A vertical arrangement of UI nodes with configurable spacing.
Nodes can be reordered and added/removed at any time.
Nodes always appear at their minimum size vertically, regardless of alignment. Horizontal alignment still applies.
Implementations
Sourceimpl VStack
impl VStack
pub fn new() -> Self
Sourcepub fn with_child(self, index: NodeIndex) -> Self
pub fn with_child(self, index: NodeIndex) -> Self
Add a new child to the stack.
Sourcepub fn with_align(self, align: (Alignment, Alignment)) -> Self
pub fn with_align(self, align: (Alignment, Alignment)) -> Self
Sourcepub fn with_spacing(self, spacing: f32) -> Self
pub fn with_spacing(self, spacing: f32) -> Self
Set the spacing between children. Defaults to 0.
No spacing appears before the first child or after the last child.
Sourcepub fn set_spacing(&mut self, spacing: f32)
pub fn set_spacing(&mut self, spacing: f32)
Set the spacing between children.
See with_spacing for details.
Sourcepub fn add_child(&mut self, index: NodeIndex)
pub fn add_child(&mut self, index: NodeIndex)
Add a child to the stack. The child will appear at the end.
Sourcepub fn remove_child(&mut self, index: usize, tree: &mut UiTree) -> bool
pub fn remove_child(&mut self, index: usize, tree: &mut UiTree) -> bool
Remove a child from the stack.
Returns true if the child was removed.
Sourcepub fn set_child_position(&mut self, index: usize, position: usize) -> bool
pub fn set_child_position(&mut self, index: usize, position: usize) -> bool
Move a child to a new index.
Returns true if the child was moved.
Sourcepub fn get_child_index(&self, index: usize) -> Option<NodeIndex>
pub fn get_child_index(&self, index: usize) -> Option<NodeIndex>
Returns the tree index associated with a child at a given stack index.