pub struct PartialTree { /* private fields */ }Expand description
A UiTree that does not have a full tree structure assigned.
The API for this struct only contains a method to add a node to the tree and a method to complete the tree. This comes at the benefit of not requiring a root node at construction.
It is used internally by the ui! macro, but can also be used manually.
Implementations